==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/dochazka/view_vkladani_dochazky.php <==
<?php
/**
 * stanislav.elbl, 24.12.2014
 */

namespace RonPortal\Dochazka;

use Ron\Controls\ComboBox;
use Ron\Controls\Options;
use Ron\DateUtils;
use Ron\MessageManager;
use Ron\MVC\Model;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSettings;
use RonPortal\TypRozdeleni;

/**
 * @var PravaNaOsoby $prava
 * @var bool     $povolitViceDnu
 */

$model = Model::getInstance();
$prava = $model ->getData('pravaVkladani');
$historie = $model ->getData('historie');
$povolitViceDnu = $model ->getData('povolitViceDnu');
$lzeMenitCas = $model ->getData('lzeMenitCas');
$editovatelneOperaceVkladani = $model ->getData('editovatelneOperaceVkladani');
//$comboOperace = $model ->getData('comboOperace');
//$comboKodOperace = $model ->getData('comboKodOperace');
$comboOsoba = $model ->getData('comboOsoba');
$optionsHistorie = $model ->getData('vyberPruchodu');
/** @var ComboBox $comboTerminal */
$comboTerminal = $model ->getData('comboTerminal');
$vybranyTerminal = $model ->getData('vybranyTerminal');

/** @var Options $operaceOptions */
$operaceOptions = $model ->getData('operaceOptions');
$operace = $model ->getData('operace');
$vybranaOperace = $model ->getData('vybranaOperace');

/** @var Options $rozdeleniOptions */
$rozdeleniOptions = $model ->getData('rozdeleniOptions');
$rozdeleni = $model ->getData('rozdeleni');
/** @var TypRozdeleni $typRozdeleni */
$typRozdeleni = $model ->getData('typRozdeleni');
$vybraneRozdeleni = $model ->getData('vybraneRozdeleni');

$backaction = $model->getData('backaction');

$viceDnu = 0;
if ($povolitViceDnu) {
    if (isset($_POST['zapnoutvicednu'])) $viceDnu = 1;
    else if (isset($_POST['vicednu'])) $viceDnu = (int)$_POST['vicednu'];
}

?>
<h1><?= $historie ? RonPortalSettings::getValue(RonPortalSettings::HISTORIE_NADPIS) : TextManager::_('Vkladani_operace') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<?php if (RonPortalSettings::getIntValue('vkladani_povolit_terminal', 1)) {?>
    <div id="vlozeni_terminalem" class="vkladani_link margin-top-2"><a href="?menuid=vlozeni&terminalmode=1<?= $backaction ? "&backaction=$backaction" : "" ?>"><?= TextManager::_('Vlozeni_bez_podrobnosti') ?></a></div>
<?php } ?>

<form method="post" name="vkladaniformular" action="?menuid=vlozeni">

<input type="hidden" name="vkladaniaction" value="<?= $historie ? 'vlozdohistorie' : 'provedvlozeni' ?>" />
<input type="hidden" name="backaction" value="<?= $backaction ?>" />
<input type="hidden" name="vicednu" value="<?= $viceDnu ?>" />

<?php if ( RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_KARTA, 1) == 3) { ?>
    <!-- pro nacteni IP pomoci Java -->
    <!-- NEPODPOROVANO ! ! ! -->
    <input type="hidden" name="IPAdresaJava" value="x" />
<?php } ?>

<div class='form middle-form'>

    <div class="form-content">
        <?php if (!$viceDnu  &&  $povolitViceDnu) { ?>
            <!-- Tlacitko pro zapnuti vice dnu -->
            <div class="row">
                <span class="col col-3"></span>
                <span class="col col-9">
                    <!-- <form method="post" action="?menuid=vlozeni&vicednu=1"> -->
                    <input type="submit" name="zapnoutvicednu" class="button" value="<?= TextManager::_('Vice_dnu') ?>" />
                    <!-- </form> -->
                </span>
            </div>
        <?php } ?>


        <!-- Vyber zamestnance -->
        <?php
            $datumoperace = isset($_POST['datumoperace']) ? $_POST['datumoperace'] : null;
            $datumoperacedo = isset($_POST['datumoperacedo']) ? $_POST['datumoperacedo'] : null;
            $casoperace = isset($_POST['casoperace']) ? $_POST['casoperace'] : null;
            //$vicednu = $povolitvicednu ? $_GET['vicednu'] : 0;

            if (!$datumoperace) $datumoperace = date('j.n.Y');

            try {
                $pomdatum = DateUtils::dateStringToTimestamp($datumoperace);
            } catch (\Exception $e) {
                $pomdatum = time();
            }

            Prava::nastavObdobiProPrava($pomdatum, $pomdatum);
        ?>

        <div class="row">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Osoba') ?> </div>
            <div class="col col-12 col-sm-9">
                <?php
                    $comboOsoba ->render();
                ?>
            </div>
        </div>

        <!-- vyber operace -->
        <div class="row">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Operace') ?> </div>
            <div class="col col-12 col-sm-9 js-hide" id="vyberOperace">
                <span class="input-group"> <!-- pouzije se, pokud nefunguje js, jinak se skryje -->
                    <?php ComboBox::renderComboFromArray($operaceOptions ->data, 'operace',
                        isset($_POST['operace']) ? $_POST['operace'] : null,
                        'id="vyberOperaceProVkladani" ' . MessageManager::getClassHtml('operace')) ?>
                </span>
            </div>
            <div class="col col-12 col-sm-6 js-show hidden">
                <input id="operace2" class="form-input" name="operace2" maxlength="40" data-ronselect-class="ronselect form-input" <?= MessageManager::getClassHtml('operace') ?> <?= MessageManager::getTitleHtml('operace') ?>>
            </div>
            <div class="col col-3 js-show hidden desktop-only">
                <input id="kodOperace2" class="form-input" name="kodOperace2" maxlength="10" data-ronselect-class="ronselect form-input" <?= MessageManager::getClassHtml('operace') ?> <?= MessageManager::getTitleHtml('operace') ?>>
            </div>
        </div>

        <?php if ($rozdeleniOptions) { ?>
            <!-- vyber rozdeleni -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= StringUtils::htmlTextConvert($typRozdeleni ->popis) ?> </div>
                <div class="col col-12 col-sm-9 js-hide" id="vyberOperace">
                    <span id="vyberRozdeleni"> <!-- pouzije se, pokud nefunguje js, jinak se skryje -->
                        <?php ComboBox::renderComboFromArray($rozdeleniOptions ->data, 'rozdeleni',
                            isset($_POST['rozdeleni']) ? $_POST['rozdeleni'] : null,
                            'id="vyberRozdeleniProVkladani"') ?>
                    </span>
                </div>
                <div class="col col-12 col-sm-6 js-show hidden">
                    <input id="rozdeleni2" class="form-input" name="rozdeleni2" data-ronselect-class="ronselect form-input" >
                </div>
                <div class="col col-sm-3 js-show hidden">
                    <input id="kodRozdeleni2" class="form-input" name="kodRozdeleni2" data-ronselect-class="ronselect form-input" maxlength="30">
                </div>
            </div>
        <?php } ?>

        <?php if ($comboTerminal  ||  $vybranyTerminal) { ?>
            <!-- vyber nebo zobrazeni terminalu -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Terminal') ?></div>
                <div class="col col-12 col-sm-9">
                    <?php if ($comboTerminal) {
                        $comboTerminal ->render();
                    } else {
                        echo StringUtils::htmlTextConvert($vybranyTerminal['popis']) . ' (' . StringUtils::htmlTextConvert($vybranyTerminal['kod']) . ')';
                    }?>
                </div>
            </div>
        <?php } ?>

    <!--    <div class="row">-->
    <!--        <div class="col col1">&nbsp;</div>-->
    <!--        <div class="col col2"></div>-->
    <!--    </div>-->

        <?php if ($lzeMenitCas || RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)) { ?>
            <!-- zadani data -->
            <div class="row top-margin">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_($viceDnu ? 'Datum_od' : 'Datum') ?> </div>
                <div class="col col-12 col-sm-9">
                    <input type="text" name="datumoperace" id="datumOperace" value="<?= StringUtils::htmlTextConvert($datumoperace) ?>" maxlength="10" <?= MessageManager::getClassHtml('datumoperace') ?> <?= MessageManager::getTitleHtml('datumoperace') ?>/>
                </div>
            </div>

            <?php if ($viceDnu) { ?>
                <!-- datum do -->
                    <div class="row">
                        <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Datum_do') ?> </div>
                        <div class="col col-12 col-sm-9">
                            <input type="text" name="datumoperacedo" value="<?= StringUtils::htmlTextConvert($datumoperacedo ?: date('j.n.Y')) ?>" maxlength="10" />
                        </div>
                    </div>
            <?php } ?>

            <!-- cas operace -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Cas') ?> </div>
                <div class="col col-12 col-sm-9">
                    <input type="text" name="casoperace" id="casOperace" value="<?= StringUtils::htmlTextConvert($casoperace ?: date('G:i:s')) ?>" maxlength="8" <?= MessageManager::getClassHtml('casoperace') ?> <?= MessageManager::getTitleHtml('casoperace') ?>/>
                    <?php
                        if (!$historie  &&  RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)  &&  $optionsHistorie) {
                            // je povolen vyber casu podle historie pruchodu
                            $comboHistorie = new ComboBox('pruchody');
                            $comboHistorie ->className = 'form-input';
                            $comboHistorie ->data = $optionsHistorie;
                            $comboHistorie ->htmlParams = 'style="display:none;" id="pruchody"';
                            $comboHistorie ->render();
                        }
                    ?>
                </div>
            </div>

    <!--        <tr>-->
    <!--            <td>&nbsp;</td>-->
    <!--            <td></td>-->
    <!--        </tr>-->
        <?php } ?>

        <!-- poznamka -->
        <div class="row top-margin">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Poznamka') ?></div>
            <div class="col col-12 col-sm-9">
                <input class="form-input" type="text" name="poznamka" value="<?=
                    isset($_POST['poznamka']) ? StringUtils::htmlTextConvert($_POST['poznamka']) : ''
                ?>" size="40" maxlength="40" />
            </div>
        </div>

    </div>

    <div class="buttons">
        <input type="submit" class="submitbutton" value="<?= TextManager::_('form.Insert') ?>" />
        <?php if (RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)) { ?>
            &nbsp;&nbsp;
            <input type="submit" name="bezuzavreni" id="btn_vlozit_bez_uzavreni" class="submitbutton" value="<?= TextManager::_('Vlozit_bez_uzavreni') ?>"  />
        <?php } ?>
    </div>
</div>

</form>

<script type="text/javascript">
    ronPortal.vkladaniDochazky({
        vkladaniPodleHistorie: <?= RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE) ? 1 : 0 ?>,
        editovatelneOperaceVkladani: <?= json_encode($editovatelneOperaceVkladani) ?>,
        operace: <?= json_encode($operace) ?>,
        muzeMenitCas : <?= $prava ->priznak ?>,
        rozdeleni: <?= json_encode($rozdeleni) ?>,
        vybraneRozdeleni: <?= $vybraneRozdeleni ? json_encode(StringUtils::jsonText($vybraneRozdeleni)) : 'null' ?>,
        vybranaOperace: <?= $vybranaOperace ? json_encode(StringUtils::jsonText($vybranaOperace)) : 'null' ?>
    });
</script>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/dochazka/view_vkladani_dochazky.php <==
<?php
/**
 * stanislav.elbl, 24.12.2014
 */

namespace RonPortal\Dochazka;

use Ron\Controls\ComboBox;
use Ron\Controls\Options;
use Ron\DateUtils;
use Ron\MessageManager;
use Ron\MVC\Model;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSettings;
use RonPortal\Security;
use RonPortal\TypRozdeleni;

/**
 * @var PravaNaOsoby $prava
 * @var bool     $povolitViceDnu
 */

$model = Model::getInstance();
$prava = $model ->getData('pravaVkladani');
$historie = $model ->getData('historie');
$povolitViceDnu = $model ->getData('povolitViceDnu');
$lzeMenitCas = $model ->getData('lzeMenitCas');
$editovatelneOperaceVkladani = $model ->getData('editovatelneOperaceVkladani');
//$comboOperace = $model ->getData('comboOperace');
//$comboKodOperace = $model ->getData('comboKodOperace');
$comboOsoba = $model ->getData('comboOsoba');
$optionsHistorie = $model ->getData('vyberPruchodu');
/** @var ComboBox $comboTerminal */
$comboTerminal = $model ->getData('comboTerminal');
$vybranyTerminal = $model ->getData('vybranyTerminal');

/** @var Options $operaceOptions */
$operaceOptions = $model ->getData('operaceOptions');
$operace = $model ->getData('operace');
$vybranaOperace = $model ->getData('vybranaOperace');

/** @var Options $rozdeleniOptions */
$rozdeleniOptions = $model ->getData('rozdeleniOptions');
$rozdeleni = $model ->getData('rozdeleni');
/** @var TypRozdeleni $typRozdeleni */
$typRozdeleni = $model ->getData('typRozdeleni');
$vybraneRozdeleni = $model ->getData('vybraneRozdeleni');

$backaction = $model->getData('backaction');

$viceDnu = 0;
if ($povolitViceDnu) {
    if (isset($_POST['zapnoutvicednu'])) $viceDnu = 1;
    else if (isset($_POST['vicednu'])) $viceDnu = (int)$_POST['vicednu'];
}

?>
<h1><?= $historie ? RonPortalSettings::getValue(RonPortalSettings::HISTORIE_NADPIS) : TextManager::_('Vkladani_operace') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<?php if (!$historie  &&  RonPortalSettings::getIntValue('vkladani_povolit_terminal', 1)) {?>
    <div id="vlozeni_terminalem" class="vkladani_link margin-top-2"><a href="?menuid=vlozeni&terminalmode=1<?= $backaction ? "&backaction=$backaction" : "" ?>"><?= TextManager::_('Vlozeni_bez_podrobnosti') ?></a></div>
<?php } ?>

<form method="post" name="vkladaniformular" action="?menuid=vlozeni">

<input type="hidden" name="vkladaniaction" value="<?= $historie ? 'vlozdohistorie' : 'provedvlozeni' ?>" />
<input type="hidden" name="backaction" value="<?= $backaction ?>" />
<input type="hidden" name="vicednu" value="<?= $viceDnu ?>" />
<?= Security::csrfHiddenInput() ?>

<?php if ( RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_KARTA, 1) == 3) { ?>
    <!-- pro nacteni IP pomoci Java -->
    <!-- NEPODPOROVANO ! ! ! -->
    <input type="hidden" name="IPAdresaJava" value="x" />
<?php } ?>

<div class='form middle-form'>

    <div class="form-content">
        <?php if (!$viceDnu  &&  $povolitViceDnu) { ?>
            <!-- Tlacitko pro zapnuti vice dnu -->
            <div class="row">
                <span class="col col-3"></span>
                <span class="col col-9">
                    <!-- <form method="post" action="?menuid=vlozeni&vicednu=1"> -->
                    <input type="submit" name="zapnoutvicednu" class="button" value="<?= TextManager::_('Vice_dnu') ?>" />
                    <!-- </form> -->
                </span>
            </div>
        <?php } ?>


        <!-- Vyber zamestnance -->
        <?php
            $datumoperace = isset($_POST['datumoperace']) ? $_POST['datumoperace'] : null;
            $datumoperacedo = isset($_POST['datumoperacedo']) ? $_POST['datumoperacedo'] : null;
            $casoperace = isset($_POST['casoperace']) ? $_POST['casoperace'] : null;
            //$vicednu = $povolitvicednu ? $_GET['vicednu'] : 0;

            if (!$datumoperace) $datumoperace = date('j.n.Y');

            try {
                $pomdatum = DateUtils::dateStringToTimestamp($datumoperace);
            } catch (\Exception $e) {
                $pomdatum = time();
            }

            Prava::nastavObdobiProPrava($pomdatum, $pomdatum);
        ?>

        <div class="row">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Osoba') ?> </div>
            <div class="col col-12 col-sm-9">
                <?php
                    $comboOsoba ->render();
                ?>
            </div>
        </div>

        <!-- vyber operace -->
        <div class="row">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Operace') ?> </div>
            <div class="col col-12 col-sm-9 js-hide" id="vyberOperace">
                <span class="input-group"> <!-- pouzije se, pokud nefunguje js, jinak se skryje -->
                    <?php ComboBox::renderComboFromArray($operaceOptions ->data, 'operace',
                        isset($_POST['operace']) ? $_POST['operace'] : null,
                        'id="vyberOperaceProVkladani" ' . MessageManager::getClassHtml('operace')) ?>
                </span>
            </div>
            <div class="col col-12 col-sm-6 js-show hidden">
                <input id="operace2" class="form-input" name="operace2" maxlength="40" data-ronselect-class="ronselect form-input" <?= MessageManager::getClassHtml('operace') ?> <?= MessageManager::getTitleHtml('operace') ?>>
            </div>
            <div class="col col-3 js-show hidden desktop-only">
                <input id="kodOperace2" class="form-input" name="kodOperace2" maxlength="10" data-ronselect-class="ronselect form-input" <?= MessageManager::getClassHtml('operace') ?> <?= MessageManager::getTitleHtml('operace') ?>>
            </div>
        </div>

        <?php if ($rozdeleniOptions) { ?>
            <!-- vyber rozdeleni -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= StringUtils::htmlTextConvert($typRozdeleni ->popis) ?> </div>
                <div class="col col-12 col-sm-9 js-hide" id="vyberOperace">
                    <span id="vyberRozdeleni"> <!-- pouzije se, pokud nefunguje js, jinak se skryje -->
                        <?php ComboBox::renderComboFromArray($rozdeleniOptions ->data, 'rozdeleni',
                            isset($_POST['rozdeleni']) ? $_POST['rozdeleni'] : null,
                            'id="vyberRozdeleniProVkladani"') ?>
                    </span>
                </div>
                <div class="col col-12 col-sm-6 js-show hidden">
                    <input id="rozdeleni2" class="form-input" name="rozdeleni2" data-ronselect-class="ronselect form-input" >
                </div>
                <div class="col col-sm-3 js-show hidden">
                    <input id="kodRozdeleni2" class="form-input" name="kodRozdeleni2" data-ronselect-class="ronselect form-input" maxlength="30">
                </div>
            </div>
        <?php } ?>

        <?php if ($comboTerminal  ||  $vybranyTerminal) { ?>
            <!-- vyber nebo zobrazeni terminalu -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Terminal') ?></div>
                <div class="col col-12 col-sm-9">
                    <?php if ($comboTerminal) {
                        $comboTerminal ->render();
                    } else {
                        echo StringUtils::htmlTextConvert($vybranyTerminal['popis']) . ' (' . StringUtils::htmlTextConvert($vybranyTerminal['kod']) . ')';
                    }?>
                </div>
            </div>
        <?php } ?>

    <!--    <div class="row">-->
    <!--        <div class="col col1">&nbsp;</div>-->
    <!--        <div class="col col2"></div>-->
    <!--    </div>-->

        <?php if ($lzeMenitCas || RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)) { ?>
            <!-- zadani data -->
            <div class="row top-margin">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_($viceDnu ? 'Datum_od' : 'Datum') ?> </div>
                <div class="col col-12 col-sm-9">
                    <input type="text" name="datumoperace" id="datumOperace" value="<?= StringUtils::htmlTextConvert($datumoperace) ?>" maxlength="10" <?= MessageManager::getClassHtml('datumoperace') ?> <?= MessageManager::getTitleHtml('datumoperace') ?>/>
                </div>
            </div>

            <?php if ($viceDnu) { ?>
                <!-- datum do -->
                    <div class="row">
                        <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Datum_do') ?> </div>
                        <div class="col col-12 col-sm-9">
                            <input type="text" name="datumoperacedo" value="<?= StringUtils::htmlTextConvert($datumoperacedo ?: date('j.n.Y')) ?>" maxlength="10" />
                        </div>
                    </div>
            <?php } ?>

            <!-- cas operace -->
            <div class="row">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Cas') ?> </div>
                <div class="col col-12 col-sm-9">
                    <input type="text" name="casoperace" id="casOperace" value="<?= StringUtils::htmlTextConvert($casoperace ?: date('G:i:s')) ?>" maxlength="8" <?= MessageManager::getClassHtml('casoperace') ?> <?= MessageManager::getTitleHtml('casoperace') ?>/>
                    <?php
                        if (!$historie  &&  RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)  &&  $optionsHistorie) {
                            // je povolen vyber casu podle historie pruchodu
                            $comboHistorie = new ComboBox('pruchody');
                            $comboHistorie ->className = 'form-input';
                            $comboHistorie ->data = $optionsHistorie;
                            $comboHistorie ->htmlParams = 'style="display:none;" id="pruchody"';
                            $comboHistorie ->render();
                        }
                    ?>
                </div>
            </div>

    <!--        <tr>-->
    <!--            <td>&nbsp;</td>-->
    <!--            <td></td>-->
    <!--        </tr>-->
        <?php } ?>

        <!-- poznamka -->
        <div class="row top-margin">
            <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Poznamka') ?></div>
            <div class="col col-12 col-sm-9">
                <input class="form-input" type="text" name="poznamka" value="<?=
                    isset($_POST['poznamka']) ? StringUtils::htmlTextConvert($_POST['poznamka']) : ''
                ?>" size="40" maxlength="40" />
            </div>
        </div>

    </div>

    <div class="buttons">
        <input type="submit" class="submitbutton" value="<?= TextManager::_('form.Insert') ?>" />
        <?php if (RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE)) { ?>
            &nbsp;&nbsp;
            <input type="submit" name="bezuzavreni" id="btn_vlozit_bez_uzavreni" class="submitbutton" value="<?= TextManager::_('Vlozit_bez_uzavreni') ?>"  />
        <?php } ?>
    </div>
</div>

</form>

<script type="text/javascript">
    ronPortal.vkladaniDochazky({
        vkladaniPodleHistorie: <?= RonPortalSettings::getIntValue(VkladaniDochazkyController::SETTINGS_PODLE_HISTORIE) ? 1 : 0 ?>,
        editovatelneOperaceVkladani: <?= json_encode($editovatelneOperaceVkladani) ?>,
        operace: <?= json_encode($operace) ?>,
        muzeMenitCas : <?= $prava ->priznak ?>,
        rozdeleni: <?= json_encode($rozdeleni) ?>,
        vybraneRozdeleni: <?= $vybraneRozdeleni ? json_encode(StringUtils::jsonText($vybraneRozdeleni)) : 'null' ?>,
        vybranaOperace: <?= $vybranaOperace ? json_encode(StringUtils::jsonText($vybranaOperace)) : 'null' ?>
    });
</script>
